##  Previewing the Survey
After designing your survey, you are directed to the Preview tab. The preview feature provides you with an accurate representation of how the survey form will appear to recipients.
In the preview tab, the survey shows only the first fact sheet from the scoped fact sheets of the survey. Any changes made in the preview mode are not saved to the fact sheet; hence, it is an ideal platform for you to test configurations such as conditionality, calculated fields, etc. However, sections containing fact sheet relations are shown in a read-only state.
![Previewing the Survey](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275431a07a44101481cea7f5ca0a68cd_LowRes.png)
Previewing the Survey
